
/*
© Copyright 2009 Travancore Analytics Pvt.Ltd. All rights reserved.

PeriodicTable:PeriodicTable.js

Handles the Periodic table functionalities.
*/

  //Total number of elements  
  var TOTAL_NO_OF_ELEMENTS=118;
  
  //Array to hold elements details
  var results = new Array;
  
  //Atomic number of the element whose details is being displayed
  var currentAtomicNumber=0;
  
  //Text color for Symbols
  var solidColor="rgb(0, 0, 0)";
  var liquidColor="rgb(173, 3, 3)";
  var gasColor="rgb(128, 0, 133)";
  var unknownColor="rgb(0, 24, 255)";
  
//
// Function: loadPeriodicTable()
// Load the periodic table
//
function loadPeriodicTable()
{     
    var xmlDocument= getPeriodicTableXML();    
     
     //In results array, the details of the element having atomic number 1 is stored is results[1].
     // results[0], is not using. So just entering default values.      
     results[results.length] = {
                    atomicNumber:0,
                    name: 0,
                    symbol: 0,
                    massNumber:0,
                    state:0,                   
                };   

     //Load element details in to results array
     loadResults(xmlDocument);
    
     //Show the elements
     showPeriodicTableElements();
     
     document.getElementById("rightArrow").title=MORE_DETAILS_TOOL_TIP_SHOW; 
     setData("warningText",MORE_DETAILS_WARNING_MSG);

}

//
// Function: getPeriodicTableXML()
// Return the xm document 
//
function getPeriodicTableXML()
{
        var XmlHTTP = new XMLHttpRequest();

        if(XmlHTTP === null)
            return false;
        XmlHTTP.open("get", "Elements.xml", false);
        XmlHTTP.send("");
        var xDoc = XmlHTTP.responseXML;

        return xDoc;

}


//
// Function: loadResults()
// Load the results array with xml data 
//
function loadResults(xmlDocument)
{

    for(var i=0;i<TOTAL_NO_OF_ELEMENTS;i++)
    {
     
        var element= xmlDocument.getElementsByTagName("element")[i];  

        var atomicNumber=getNodeData(element,"atomicNumber");
        var name=getNodeData(element,"name");
        var symbol=getNodeData(element,"symbol");
        var massNumber=getNodeData(element,"massNumber");
        var state=getNodeData(element,"state");               
  
          var category=getNodeData(element,"category");
          category=category==null || category=="" ?0:eval(category);


          var x=getNodeData(element,"x");
          var y=getNodeData(element,"y");
          var lewisDot=getNodeData(element,"lewisDot");            
          var mp=getNodeData(element,"mp");           
          var bp=getNodeData(element,"bp");
          var density=getNodeData(element,"density");
          var percentage=getNodeData(element,"percentage");
          var year=getNodeData(element,"year");
          var group=getNodeData(element,"group");
          var period=getNodeData(element,"period");
          var configuration=getNodeData(element,"configuration");
          var thermalconductivity=getNodeData(element,"thermalconductivity");
          var spHeatCapacity=getNodeData(element,"spHeatCapacity");
          var heatOfVaporization=getNodeData(element,"heatOfVaporization");
          var electronegativity=getNodeData(element,"electronegativity");
          var atomicRadius=getNodeData(element,"atomicRadius");
          var atomicVolume=getNodeData(element,"atomicVolume");
          var covalentRadius=getNodeData(element,"covalentRadius");
          var electricalconductivity=getNodeData(element,"electricalconductivity");
          var color=getNodeData(element,"color");
          var block=getNodeData(element,"block");
          
          

             results[results.length] = {
                            atomicNumber: atomicNumber,
                            name: name,
                            symbol: symbol,
                            massNumber:massNumber,
                            state:state,
                            category:category,
                            lewisDot:lewisDot,
                            mp:mp,                           
                            bp:bp,
                            density:density,
                            percentage:percentage,
                            year:year,
                            group:group,
                            period:period,
                            configuration:configuration,                         
                            thermalconductivity:thermalconductivity,
                            spHeatCapacity:spHeatCapacity,
                            heatOfVaporization:heatOfVaporization,                      
                            electronegativity:electronegativity,
                            atomicRadius:atomicRadius,
                            atomicVolume:atomicVolume,
                            covalentRadius:covalentRadius,
                            electricalconductivity:electricalconductivity,
                            color:color,
                            block:block,
                            x:x,
                            y:y
                           
                        };           
   }
      
}       
         


//
// Function: showPeriodicTableElements()
// Shows the periodic table 
//
function showPeriodicTableElements()
{
    for(var i=0;i<TOTAL_NO_OF_ELEMENTS;i++)
    {
        var atomicNumber=i+1;
        
        //Creates Html controls for element
        createElement(atomicNumber);
        
        //Sets element detaiils   
        setData("symbol_"+atomicNumber,results[atomicNumber].symbol);
        
        //Uncomment the following line, if atomic number is to be displayed along with symbol in periodic table view.
        /*  setData("atomNum_"+atomicNumber,atomicNumber);*/
        applyFontColorForSymbol("symbol_"+atomicNumber,results[atomicNumber].state);
        
        //Sets the background image for the element based on the element category
        setElementBgImage(atomicNumber,results[atomicNumber].category);
    }
}

//
// Function: getNodeData()
// Returns the node data
//      
function getNodeData(element, nodeName)
{
    var child;

    for (child = element.firstChild; child != null; child = child.nextSibling) {
        if (child.nodeName == nodeName)
        {
            if(child.firstChild)
            {
                return child.firstChild.data;
            }
            else
            {
              return "-";
            }
        }
    }

    return "-";
}

//
// Function: setElementBgImage()
// Sets the element's backgroung image, based on the category
//  
function setElementBgImage(atomicNumber,category,isMouseOver)
{
        var image=document.getElementById("image_"+atomicNumber);
        if(isMouseOver)  
        {
            image.src="Images/bg_"+category+"_ovr.png";
        }
        else
        {
            image.src="Images/bg_"+category+".png";
        }
 }


//
// Function: applyFontColorForSymbol()
// Sets the font color for symbol based on the element's state
//             
function applyFontColorForSymbol(symbolId, state)
{
    var symbol=   document.getElementById(symbolId);
    if(symbol)
    {
        if(state=="Solid")
        {
            symbol.style.color=solidColor;
        }    
        else if(state=="Gas")
        {
            symbol.style.color=gasColor;
        }    
        else if(state=="Liquid")
        {
            symbol.style.color=liquidColor;
        }       
        else if(state=="Unknown")
        {
            symbol.style.color=unknownColor;
        }

    }
}

//
// Function: showElementDetailsView()
// Shows the details view
// 
function showElementDetailsView(event)
{
    //gets the atomic number from the event
    var atomicNumber= getAtomicNumberFromEvent(event);
    
    currentAtomicNumber=atomicNumber;
    
    //Change the backgroung image, mouse over image    
    setElementBgImage(atomicNumber,results[atomicNumber].category,true)  ;  
    
    //Gets the x and y posiotions of the element
    var elementPos_x=document.getElementById("element_"+atomicNumber).offsetLeft;
    var elementPos_y=document.getElementById("element_"+atomicNumber).offsetTop;
    
    var detailsView= document.getElementById("detailsView");

    detailsView.style.position="absolute";
    
   var category= results[atomicNumber].category;
   
   if(category==0 || category==1 || category==10 || category==2 || category==6 || category==7 || category==8 || category==9)
   {
        detailsView.style.width=110+"px";
        detailsView.style.height=82+"px";
        document.getElementById("deailsViewBg").style.width=109+"px";
        document.getElementById("deailsViewBg").style.height=82+"px";    
   }
   
   else
   {
        detailsView.style.width=86+"px";
        detailsView.style.height=105+"px";
        document.getElementById("deailsViewBg").style.width=85+"px";
        document.getElementById("deailsViewBg").style.height=105+"px";
   }
   
   if(category==0 || category==1|| category==2)
   {
        detailsView.style.left=elementPos_x+26+"px";
        document.getElementById("detailsTextDiv").style.left=25+"px";
   }
   
  if(category==8||category==9||category==7||category==6||category==10)
   {
        detailsView.style.left=elementPos_x-109+"px";
        document.getElementById("detailsTextDiv").style.left=1+"px";
   } 
   if(category==3 || category==4)
   {
       detailsView.style.top=elementPos_y-105+"px";
       detailsView.style.left=elementPos_x-72+"px";
       document.getElementById("detailsTextDiv").style.left=1+"px";
   }
   
   if(category==5)
   {
        detailsView.style.top=elementPos_y-105+"px";
        detailsView.style.left=elementPos_x-32+"px";
        document.getElementById("detailsTextDiv").style.left=1+"px";
   }
   
   if(category==0 || category==1 || category==10 || category==2 || category==6 || category==7 || category==8 || category==9)
   {   
        detailsView.style.top=elementPos_y+13+"px";         
   }
   
   
      setDetailsData(atomicNumber);
      
       if(!isArrowAtLeft)
        {
            fillMoreViewData(atomicNumber); 
        }
}

//
// Function: setDetailsData()
// Sets the details data
// 
function setDetailsData(atomicNumber)
{
    drowlewisDots(atomicNumber);

    document.getElementById("deailsViewBg").src="Images/detailsBg_"+results[atomicNumber].category+".png";
    txt_atomicNumber.innerHTML=results[atomicNumber].atomicNumber;
    document.getElementById("txt_name").innerHTML=results[atomicNumber].name;    
    document.getElementById("txt_symbol").innerHTML=results[atomicNumber].symbol;
    document.getElementById("txt_small_symbol").innerHTML=results[atomicNumber].symbol;
    txt_mass.innerHTML=results[atomicNumber].massNumber;
   
    applyFontColorForSymbol("txt_symbol", results[atomicNumber].state);
    applyFontColorForSymbol("txt_small_symbol", results[atomicNumber].state);
    document.getElementById("detailsView").style.display="block";
}

//
// Function: mouseOutElement()
// Method to handle the mouse out of element. It hides the detials view
// 
function mouseOutElement(event)
{
        var elId= getAtomicNumberFromEvent(event);    
        setElementBgImage(elId,results[elId].category,false)  ;  
        clearMoreView();
        document.getElementById("detailsView").style.display="none";
}

//
// Function: getAtomicNumberFromEvent()
// Method to handle the mouse out of element. It hides the detials view
// 
function getAtomicNumberFromEvent(event)
{
    var el=event.target;
    var elemId=el.id;
    var lastIndexOf_=el.id.lastIndexOf("_");  
    return elemId.substring(lastIndexOf_+1); 
}


//
// Function: createElement()
// Creates HTML controls for an element
// 
function createElement(atomicNumber)
{
      //Creates the outer element div
      var element=document.createElement("div");
      element.setAttribute("id", "element_"+atomicNumber);
      element.style.top=eval(results[atomicNumber].y)+16+"px";
      element.style.left=eval((results[atomicNumber].x))+26+"px";
      element.setAttribute("class", "elementClass");
  
       //Creates the image for the element's background
      var imageId=document.createElement("img");
      imageId.setAttribute("id", "image_"+atomicNumber);
      imageId.setAttribute("class", "imageClass");
          
        //Creates a dic to display the atomic number     
      var atomic=document.createElement("div");
      atomic.setAttribute("id", "atomNum_"+atomicNumber);
      atomic.setAttribute("class", "atomicClass");
    
       //Creates a div to display the element symbol 
      var symbol=document.createElement("div");
      symbol.setAttribute("id", "symbol_"+atomicNumber);  
      symbol.setAttribute("class", "symbolClass");  
    
       //Register mouse over and mouse out event for the element 
      element.addEventListener("mouseover",showElementDetailsView, false);
      element.addEventListener("mouseout",mouseOutElement, false);    
           
      //Add the controls
      element.appendChild(imageId);
      element.appendChild(atomic);
      element.appendChild(symbol);
      document.getElementById("front").appendChild(element);
}


//
// Function: hideDetailsView()
// Hide the details view
//
function hideDetailsView(event)
{
    if(currentAtomicNumber>0)
    {
        var elId= currentAtomicNumber;    
        setElementBgImage(elId,results[elId].category,false)  ;  
        document.getElementById("detailsView").style.display="none";
        currentAtomicNumber=0;
    }
}


//
// Function: drowlewisDots()
// Drow the lewis dots in details view
//
function drowlewisDots(atomicNumber)
{
            var lewisDots=results[atomicNumber].lewisDot;
            lewisDots=lewisDots==null?"":lewisDots;
            var lewisDotString =lewisDots.split(",");
            var length=lewisDotString.length;
            if(length==8)
            {
                for(var i=0;i<8;i++)
                {
                        var image=document.getElementById("lewisDot_"+(i+1));                
                        image.src="Images/lewisDot_"+lewisDotString[i]+".png";
                }                      
            }          
}


//
// Function: getCategoryNameFromId()
// Returns the category name from the category Id.
//
function getCategoryNameFromId(id)
{
    switch(id)
    {
        case 0:
        {
           return "Hydrogen";
           break;
        }
        case 1:
        {
            return "Alkali metals";
        }
        case 2:
        {
             return "Alkaline earth metals";
            
        }
        case 3:
        {
            return "Lanthanoids";
            
        }
        case 4:
        {
            return "Actinoids";
        }
        case 5:
        {
            return "Transition metals";
        }
        case 6:
        {
            return "Poor metals";
        }

        case 7:
        {
            return "Other Non Metals";
        }
        case 8:
        {
            return "Noble Gases";
        }
        case 9:
        {
            return "Halogens";
        }
        case 10:
        {
            return "Unknown";
        }
    }
}

//
// Function: taUrlClickHandler()
// Method to handle the click event of TA's URL.
//
function taUrlClickHandler(event)
{
  if (window.widget) {
        widget.openURL("http://www.travancoreanalytics.com");
        if (event) {
            event.stopPropagation();
            event.preventDefault();
        }
        return false;
    }
   
}